@@ -5,12 +5,12 @@
 #' detection and extraction of Chinese numerals in character objects and string.
 #'
 #' @section Warnings: The precision of converting large numbers and long
-#'   decimals is limited in base R. You might be able to improve the accurancy
-#'   by running \code{options(digits = 22)}.
+#'   decimals is limited in base R. You might be able to improve the accuracy by
+#'   running \code{options(digits = 22)}.
 #'
 #' @note Due to technical limitation, R package documentation cannot contain
 #'   Chinese characters. Therefore, the Chinese characters are represented in
-#'   romainized Chinese \emph{pinyin} in the documentation and substituted with
+#'   romanized Chinese \emph{pinyin} in the documentation and substituted with
 #'   \emph{"hello"} in some of the example code. Visit the GitHub page for
 #'   clearer examples with Chinese characters.
 #'
@@ -19,8 +19,7 @@
 #' @seealso GitHub page: \url{https://github.com/elgarteo/cnum}
 #'
 #' @docType package
-#' @name cnum-package
-#' @aliases cnum
+#' @keywords internal
 #' @importFrom stringr str_extract_all
 #'
-NULL
+"_PACKAGE"
